::: pagesmith.HtmlPageSplitter
    options:
      show_root_heading: true
      heading_level: 2
      show_submodules: false
::: pagesmith.PageSplitter
    options:
      show_root_heading: true
      heading_level: 1
      show_submodules: false
::: pagesmith.ChapterDetector
    options:
      show_root_heading: true
      heading_level: 1
      show_submodules: false
::: pagesmith.refine_html
    options:
      show_root_heading: true
      heading_level: 1
      show_submodules: false
